@@ -25,20 +25,21 @@
 #' @examples
 #' library(ngram)
 #' 
-#' str <- "A B A C A B B"
+#' str = "A B A C A B B"
 #' ngram_asweka(str, min=2, max=4)
 #' 
 #' @seealso \code{\link{ngram}}
 #' @keywords Tokenization
+#' @useDynLib ngram R_ng_asweka
 #' @name Tokenize-AsWeka
 #' @rdname tokenize-asweka
 #' @export
-ngram_asweka <- function(str, min=2, max=2, sep=" ")
+ngram_asweka = function(str, min=2, max=2, sep=" ")
 {
   check.is.string(str)
   check.is.posint(min)
   check.is.posint(max)
   check.is.string(sep)
   
-  .Call(ng_asweka, str, as.integer(min), as.integer(max), sep)
+  .Call(R_ng_asweka, str, as.integer(min), as.integer(max), sep)
 }
